@@ -77,8 +77,11 @@ public:
   Lum::Model::Boolean* GetFinishedModel() const;
 
   bool IsFocusedCellEditable() const;
+  bool IsCellInMarkModus() const;
   size_t GetFocusedCellValue() const;
+  size_t GetFocusedCellMarks() const;
   void SetFocusedCellValue(size_t value);
+  void SetFocusedCellMarks(size_t value);
 
   void Solve();
 };
