@@ -24,6 +24,8 @@
 #include <Lum/Base/Path.h>
 #include <Lum/Base/String.h>
 
+#include <Lum/Def/Menu.h>
+
 #include <Lum/Dlg/About.h>
 #include <Lum/Dlg/Help.h>
 #include <Lum/Dlg/Msg.h>
@@ -39,7 +41,6 @@
 #include <Lum/Dialog.h>
 #include <Lum/Image.h>
 #include <Lum/Label.h>
-#include <Lum/Menu.h>
 #include <Lum/Panel.h>
 #include <Lum/Text.h>
 #include <Lum/Toggle.h>
@@ -217,7 +218,7 @@ public:
 
     vert->Add(label);
 
-    if (Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()) {
+    if (true/*Lum::OS::display->GetTheme()->RequestFingerFriendlyControls()*/) {
       vert->AddSpace();
 
       array=new Lum::Array();
@@ -232,12 +233,12 @@ public:
       vert->Add(array);
 
       array=new Lum::Array();
-      array->SetFlex(true,true);
+      array->SetFlex(true,false);
       array->SetHorizontalCount(2);
       array->SetSpace(false,false);
 
-      array->Add(Lum::Button::Create(L"_Clear",clearAction,true,false));
-      array->Add(Lum::Toggle::Create(L"Mark",mark,true,false));
+      array->Add(Lum::Button::Create(L"_Clear",clearAction,true,true));
+      array->Add(Lum::Toggle::Create(L"Mark",mark,true,true));
 
       vert->Add(array);
 
@@ -279,21 +280,28 @@ public:
 
     SetMain(horiz);
 
-    Lum::MenuDesc *menu=new Lum::MenuDesc();
+    Lum::Def::Menu *menu=Lum::Def::Menu::Create();
 
     menu
-      ->AddMenuItemSub(_ld(menuProject))
-        ->AddMenuItemAction(_ld(menuProjectQuit),Lum::OS::qualifierControl,L"q",GetClosedAction());
-    menu
-      ->AddMenuItemSub(_(L"MENU_GAME",L"_Game"))
-        ->AddMenuItemAction(_(L"MENU_GAME_NEW",L"_Generate new game"),Lum::OS::qualifierControl,L"g",generateAction)
-        ->AddMenuItemAction(_(L"MENU_GAME_SOLVE",L"_Solve game"),Lum::OS::qualifierControl,L"s",solveAction)
-        ->AddSeparator()
-        ->AddMenuItemAction(_(L"MENU_GAME_STAT",L"S_tatistics"),Lum::OS::qualifierControl,L"t",statAction);
-    menu
-      ->AddMenuItemSub(_ld(menuHelp))
-        ->AddMenuItemAction(_ld(menuHelpHelp),helpAction)
-        ->AddMenuItemAction(_ld(menuHelpAbout),aboutAction);
+      ->GroupProject()
+        ->ActionQuit(GetClosedAction())
+      ->End()
+      ->Group(_(L"MENU_GAME",L"_Game"))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_NEW",L"_Generate new game"))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"g"),
+                                  generateAction))
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_SOLVE",L"_Solve game"))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"s"),
+                                  solveAction))
+        ->Separator()
+        ->Action(Lum::Def::Action(Lum::Def::Desc(_(L"MENU_GAME_STAT",L"S_tatistics"))
+                                  .SetShortcut(Lum::OS::qualifierControl,L"t"),
+                                  statAction))
+      ->End()
+      ->GroupHelp()
+        ->ActionHelp(helpAction)
+        ->ActionAbout(aboutAction)
+      ->End();
 
     SetMenu(menu);
 
